`timescale 1ns/1ps
//**********************************************************************
// 	Project: 
//	File: tb.v
// 	Description: 
//	Author: Noa
//  Timestamp: 
//----------------------------------------------------------------------
// Code Revision History:
// Ver:		| Author 	| Mod. Date		| Changes Made:
// v1.0.0	| Noa		| xx/xx/20xx	| Initial version
//**********************************************************************
`include "define.vh"
module tb_gw5a( 
    clk, 
    rstn,

    capture_index,
    capture_data,

    fir_valid_o,
    fir_sync_o,
    fir_data_o
);

//**********************************************************************
// --- Parameter
//**********************************************************************
`include "parameter.vh"

//**********************************************************************
// --- Test Input signal
//**********************************************************************	
	input 						clk, rstn;
	
	wire 					 	fir_valid_i;
	wire 					 	fir_sync_i;
	wire 	[DIN_WIDTH-1:0] 	fir_data_i;

//**********************************************************************
// --- Test Output signal
//**********************************************************************
	 wire								fir_rfi_o;

	 output 							fir_valid_o;
	 output					 			fir_sync_o;
	 output signed [DOUT_WIDTH-1:0]		fir_data_o;
	
	
//**********************************************************************
// --- Internal Signal Declaration
//**********************************************************************	
	output [8:0] capture_index;
	output [DOUT_WIDTH-1:0] capture_data;
	
	wire trigger;
	assign trigger = (capture_index == 128)? 1'b1:1'b0;
//**********************************************************************
// --- Module:	fir_ip_top
// --- Description:	
//**********************************************************************
	Advanced_FIR_Filter_Top Advanced_FIR_Filter_Top_isnt(
		.clk				( clk			),
		.rstn				( rstn			),
							
		.fir_rfi_o			( fir_rfi_o		),
		.fir_valid_i		( fir_valid_i	),
		.fir_sync_i			( fir_sync_i	),
		.fir_data_i			( fir_data_i	),
		
		.fir_valid_o		( fir_valid_o	),
		.fir_sync_o			( fir_sync_o	),
		.fir_data_o			( fir_data_o	)
	);
	

//**********************************************************************
// --- Module:	sim_input_gen
// --- Description:	simulation - input generator 
//**********************************************************************	
	sim_input_gen sim_input_gen_inst(
		.clk				( clk			),
		.rstn				( rstn			), 
		
		.rfi_i				( fir_rfi_o		), 
		
		.sim_valid_o		( fir_valid_i 	),
		.sim_sync_o			( fir_sync_i 	),
		.sim_data_o			( fir_data_i	)
	);
	defparam sim_input_gen_inst.DATA_WIDTH = DIN_WIDTH;
	defparam sim_input_gen_inst.NUM_CHN = NUM_CHN;
	defparam sim_input_gen_inst.NUM_CYCLE = NUM_TDM;
//**********************************************************************
// --- Module:	sim_output_storage
// --- Description:	simulation - output data storage
//**********************************************************************	
	sim_output_storage sim_output_storage_inst(
		.clk				( clk			),
		.rstn				( rstn			),  
		
		.sim_valid_i		( fir_valid_o 	),
		.sim_sync_i			( fir_sync_o 	),
		.sim_data_i			( fir_data_o	),
		
		.sim_index_o		( capture_index	),	
		.sim_data_o			( capture_data	)
	);
	defparam sim_output_storage_inst.DATA_WIDTH = DOUT_WIDTH;
	defparam sim_output_storage_inst.MEM_DEPTH = 512;
	defparam sim_output_storage_inst.NUM_CHN = 	NUM_CHN;
	defparam sim_output_storage_inst.CHN_SEL = 	CHN_SEL;

endmodule
